import pprint
import unittest
import iyzipay


class PaymentPostAuthSample(unittest.TestCase):
    def runTest(self):
        self.should_post_auth()

    def should_post_auth(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456'
        request['paymentId'] = '1'
        request['ip'] = '85.34.78.112'
        request['currency'] = 'TRY'

        # make request
        payment_post_auth = iyzipay.PaymentPostAuth()
        payment_post_auth_response = payment_post_auth.create(request, options)

        # print response
        pprint.pprint(payment_post_auth_response.read().decode())



import pprint
import unittest
import iyzipay


class ApprovalSample(unittest.TestCase):
    def runTest(self):
        self.should_approve_payment_item()
        self.should_disapprove_payment_item()

    def should_approve_payment_item(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['paymentTransactionId'] = '1'

        # make request
        approval = iyzipay.Approval()
        approval_response = approval.create(request, options)

        # print response
        pprint.pprint(approval_response.read().decode())

    def should_disapprove_payment_item(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['paymentTransactionId'] = '1'

        # make request
        disapproval = iyzipay.Disapproval()
        disapproval_response = disapproval.create(request, options)

        # print response
        pprint.pprint(disapproval_response.read().decode())


import pprint
import unittest
import iyzipay
import ast
import base64


class PaymentPreAuthSample(unittest.TestCase):
    def runTest(self):
        self.should_create_payment_with_physical_and_virtual_item_for_standard_merchant()
        self.should_create_payment_with_physical_and_virtual_item_for_market_place()
        self.should_create_payment_with_physical_and_virtual_item_for_listing_or_subscription()
        self.should_retrieve_payment()

    def should_create_payment_with_physical_and_virtual_item_for_standard_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'
        request['paidPrice'] = '1.1'
        request['installment'] = '1'
        request['basketId'] = 'B67832'
        request['paymentChannel'] = 'WEB'
        request['paymentGroup'] = 'PRODUCT'
        request['callbackUrl'] = 'https://www.merchant.com/callback'
        request['currency'] = 'TRY'

        payment_card = dict([('cardHolderName', 'John Doe')])
        payment_card['cardNumber'] = '5528790000000008'
        payment_card['expireMonth'] = '12'
        payment_card['expireYear'] = '2030'
        payment_card['cvc'] = '123'
        payment_card['registerCard'] = '0'
        request['paymentCard'] = payment_card

        buyer = dict([('id', 'BY789')])
        buyer['name'] = 'John'
        buyer['surname'] = 'Doe'
        buyer['gsmNumber'] = '+905350000000'
        buyer['email'] = 'email@email.com'
        buyer['identityNumber'] = '74300864791'
        buyer['lastLoginDate'] = '2015-10-05 12:43:35'
        buyer['registrationDate'] = '2013-04-21 15:12:09'
        buyer['registrationAddress'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        buyer['ip'] = '85.34.78.112'
        buyer['city'] = 'Istanbul'
        buyer['country'] = 'Turkey'
        buyer['zipCode'] = '34732'
        request['buyer'] = buyer

        address = dict([('address', 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1')])
        address['zipCode'] = '34732'
        address['contactName'] = 'Jane Doe'
        address['city'] = 'Istanbul'
        address['country'] = 'Turkey'
        request['shippingAddress'] = address
        request['billingAddress'] = address

        basket_items = []
        basket_item_first = dict([('id', 'BI101')])
        basket_item_first['name'] = 'Binocular'
        basket_item_first['category1'] = 'Collectibles'
        basket_item_first['category2'] = 'Accessories'
        basket_item_first['itemType'] = 'PHYSICAL'
        basket_item_first['price'] = '0.3'
        basket_items.append(basket_item_first)

        basket_item_second = dict([('id', 'BI102')])
        basket_item_second['name'] = 'Game code'
        basket_item_second['category1'] = 'Game'
        basket_item_second['category2'] = 'Online Game Items'
        basket_item_second['itemType'] = 'VIRTUAL'
        basket_item_second['price'] = '0.5'
        basket_items.append(basket_item_second)

        basket_item_third = dict([('id', 'BI103')])
        basket_item_third['name'] = 'Usb'
        basket_item_third['category1'] = 'Electronics'
        basket_item_third['category2'] = 'Usb / Cable'
        basket_item_third['itemType'] = 'PHYSICAL'
        basket_item_third['price'] = '0.2'
        basket_items.append(basket_item_third)

        request['basketItems'] = basket_items

        # make request
        payment_pre_auth = iyzipay.PaymentPreAuth()
        payment_pre_auth_response = payment_pre_auth.create(request, options)

        # get and print response
        response = payment_pre_auth_response.read().decode()
        pprint.pprint(response)

    def should_create_payment_with_physical_and_virtual_item_for_market_place(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'
        request['paidPrice'] = '1.1'
        request['installment'] = '1'
        request['basketId'] = 'B67832'
        request['paymentChannel'] = 'WEB'
        request['paymentGroup'] = 'PRODUCT'
        request['callbackUrl'] = 'https://www.merchant.com/callback'
        request['currency'] = 'TRY'

        payment_card = dict([('cardHolderName', 'John Doe')])
        payment_card['cardNumber'] = '5528790000000008'
        payment_card['expireMonth'] = '12'
        payment_card['expireYear'] = '2030'
        payment_card['cvc'] = '123'
        payment_card['registerCard'] = '0'
        request['paymentCard'] = payment_card

        buyer = dict([('id', 'BY789')])
        buyer['name'] = 'John'
        buyer['surname'] = 'Doe'
        buyer['gsmNumber'] = '+905350000000'
        buyer['email'] = 'email@email.com'
        buyer['identityNumber'] = '74300864791'
        buyer['lastLoginDate'] = '2015-10-05 12:43:35'
        buyer['registrationDate'] = '2013-04-21 15:12:09'
        buyer['registrationAddress'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        buyer['ip'] = '85.34.78.112'
        buyer['city'] = 'Istanbul'
        buyer['country'] = 'Turkey'
        buyer['zipCode'] = '34732'
        request['buyer'] = buyer

        address = dict([('address', 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1')])
        address['zipCode'] = '34732'
        address['contactName'] = 'Jane Doe'
        address['city'] = 'Istanbul'
        address['country'] = 'Turkey'
        request['shippingAddress'] = address
        request['billingAddress'] = address

        basket_items = []
        basket_item_first = dict([('id', 'BI101')])
        basket_item_first['name'] = 'Binocular'
        basket_item_first['category1'] = 'Collectibles'
        basket_item_first['category2'] = 'Accessories'
        basket_item_first['itemType'] = 'PHYSICAL'
        basket_item_first['price'] = '0.3'
        basket_item_first['subMerchantKey'] = 'sub merchant key'
        basket_item_first['subMerchantPrice'] = '0.27'
        basket_items.append(basket_item_first)

        basket_item_second = dict([('id', 'BI102')])
        basket_item_second['name'] = 'Game code'
        basket_item_second['category1'] = 'Game'
        basket_item_second['category2'] = 'Online Game Items'
        basket_item_second['itemType'] = 'VIRTUAL'
        basket_item_second['price'] = '0.5'
        basket_item_second['subMerchantKey'] = 'sub merchant key'
        basket_item_second['subMerchantPrice'] = '0.42'
        basket_items.append(basket_item_second)

        basket_item_third = dict([('id', 'BI103')])
        basket_item_third['name'] = 'Usb'
        basket_item_third['category1'] = 'Electronics'
        basket_item_third['category2'] = 'Usb / Cable'
        basket_item_third['itemType'] = 'PHYSICAL'
        basket_item_third['price'] = '0.2'
        basket_item_third['subMerchantKey'] = 'sub merchant key'
        basket_item_third['subMerchantPrice'] = '0.18'
        basket_items.append(basket_item_third)

        request['basketItems'] = basket_items

        # make request
        payment_pre_auth = iyzipay.PaymentPreAuth()
        payment_pre_auth_response = payment_pre_auth.create(request, options)

        # get and print response
        response = payment_pre_auth_response.read().decode()
        pprint.pprint(response)

    def should_create_payment_with_physical_and_virtual_item_for_listing_or_subscription(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'
        request['paidPrice'] = '1.1'
        request['installment'] = '1'
        request['basketId'] = 'B67832'
        request['paymentChannel'] = 'WEB'
        request['paymentGroup'] = 'SUBSCRIPTION'
        request['callbackUrl'] = 'https://www.merchant.com/callback'
        request['currency'] = 'TRY'

        payment_card = dict([('cardHolderName', 'John Doe')])
        payment_card['cardNumber'] = '5528790000000008'
        payment_card['expireMonth'] = '12'
        payment_card['expireYear'] = '2030'
        payment_card['cvc'] = '123'
        payment_card['registerCard'] = '0'
        request['paymentCard'] = payment_card

        buyer = dict([('id', 'BY789')])
        buyer['name'] = 'John'
        buyer['surname'] = 'Doe'
        buyer['gsmNumber'] = '+905350000000'
        buyer['email'] = 'email@email.com'
        buyer['identityNumber'] = '74300864791'
        buyer['lastLoginDate'] = '2015-10-05 12:43:35'
        buyer['registrationDate'] = '2013-04-21 15:12:09'
        buyer['registrationAddress'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        buyer['ip'] = '85.34.78.112'
        buyer['city'] = 'Istanbul'
        buyer['country'] = 'Turkey'
        buyer['zipCode'] = '34732'
        request['buyer'] = buyer

        address = dict([('address', 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1')])
        address['zipCode'] = '34732'
        address['contactName'] = 'Jane Doe'
        address['city'] = 'Istanbul'
        address['country'] = 'Turkey'
        request['shippingAddress'] = address
        request['billingAddress'] = address

        basket_items = []
        basket_item_first = dict([('id', 'BI101')])
        basket_item_first['name'] = 'Binocular'
        basket_item_first['category1'] = 'Collectibles'
        basket_item_first['category2'] = 'Accessories'
        basket_item_first['itemType'] = 'PHYSICAL'
        basket_item_first['price'] = '0.3'
        basket_items.append(basket_item_first)

        basket_item_second = dict([('id', 'BI102')])
        basket_item_second['name'] = 'Game code'
        basket_item_second['category1'] = 'Game'
        basket_item_second['category2'] = 'Online Game Items'
        basket_item_second['itemType'] = 'VIRTUAL'
        basket_item_second['price'] = '0.5'
        basket_items.append(basket_item_second)

        basket_item_third = dict([('id', 'BI103')])
        basket_item_third['name'] = 'Usb'
        basket_item_third['category1'] = 'Electronics'
        basket_item_third['category2'] = 'Usb / Cable'
        basket_item_third['itemType'] = 'PHYSICAL'
        basket_item_third['price'] = '0.2'
        basket_items.append(basket_item_third)

        request['basketItems'] = basket_items

        # make request
        payment_pre_auth = iyzipay.PaymentPreAuth()
        payment_pre_auth_response = payment_pre_auth.create(request, options)

        # get and print response
        response = payment_pre_auth_response.read().decode()
        pprint.pprint(response)

    def should_retrieve_payment(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['paymentId'] = '1'
        request['paymentConversationId'] = '123456789'

        # make request
        payment_pre_auth = iyzipay.PaymentPreAuth()
        payment_pre_auth_response = payment_pre_auth.retrieve(request, options)

        # print response
        pprint.pprint(payment_pre_auth_response.read().decode())



import pprint
import unittest
import iyzipay


class ConnectCancelSample(unittest.TestCase):
    def runTest(self):
        self.should_cancel_payment()

    def should_cancel_payment(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456'
        request['paymentId'] = '1'
        request['ip'] = '85.34.78.112'

        # make request
        cancel = iyzipay.ConnectCancel()
        cancel_response = cancel.create(request, options)

        # print response
        pprint.pprint(cancel_response.read().decode())



import pprint
import unittest
import iyzipay
import ast
import base64


class ConnectThreeDSSample(unittest.TestCase):
    def runTest(self):
        self.should_initialize_threeds_with_card()
        self.should_initialize_threeds_with_card_token()
        self.should_auth_threeds()

    def should_initialize_threeds_with_card(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'
        request['paidPrice'] = '1'
        request['installment'] = '1'
        request['buyerEmail'] = 'email@email.com'
        request['buyerId'] = 'B2323'
        request['buyerIp'] = '85.34.78.112'
        request['connectorName'] = 'connector name'
        request['callbackUrl'] = 'https://www.merchant.com/callback'
        request['currency'] = 'TRY'

        payment_card = dict([('cardHolderName', 'John Doe')])
        payment_card['cardNumber'] = '5528790000000008'
        payment_card['expireMonth'] = '12'
        payment_card['expireYear'] = '2030'
        payment_card['cvc'] = '123'
        payment_card['registerCard'] = '0'
        request['paymentCard'] = payment_card

        # make request
        three_d_s_initialize = iyzipay.ConnectThreeDSInitialize()
        three_d_s_initialize_response = three_d_s_initialize.create(request, options)

        # get and print response
        response = three_d_s_initialize_response.read().decode()
        pprint.pprint(response)

        # generate html code to redirect to BKM
        response_data_dict = ast.literal_eval(response)
        html_response = base64.b64decode(response_data_dict['threeDSHtmlContent'])
        pprint.pprint(html_response)

    def should_initialize_threeds_with_card_token(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'
        request['paidPrice'] = '1'
        request['installment'] = '1'
        request['buyerEmail'] = 'email@email.com'
        request['buyerId'] = 'B2323'
        request['buyerIp'] = '85.34.78.112'
        request['connectorName'] = 'connector name'
        request['currency'] = 'TRY'
        request['callbackUrl'] = 'https://www.merchant.com/callback'

        payment_card = dict([('cardToken', 'card token')])
        payment_card['cardUserKey'] = 'card user key'
        request['paymentCard'] = payment_card

        # make request
        three_d_s_initialize = iyzipay.ConnectThreeDSInitialize()
        three_d_s_initialize_response = three_d_s_initialize.create(request, options)

        # get and print response
        response = three_d_s_initialize_response.read().decode()
        pprint.pprint(response)

        # generate html code to redirect to BKM
        response_data_dict = ast.literal_eval(response)
        html_response = base64.b64decode(response_data_dict['threeDSHtmlContent'])
        pprint.pprint(html_response)

    def should_auth_threeds(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['paymentId'] = '1'
        request['conversationData'] = 'conversation data'

        # make request
        three_d_s_auth = iyzipay.ConnectThreeDSAuth()
        three_d_s_auth_response = three_d_s_auth.create(request, options)

        # print response
        pprint.pprint(three_d_s_auth_response.read().decode())




import pprint
import unittest
import iyzipay


class CrossBookingSample(unittest.TestCase):
    def runTest(self):
        self.should_send_money_to_sub_merchant()
        self.should_receive_money_from_sub_merchant()

    def should_send_money_to_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantKey'] = 'sub merchant key'
        request['price'] = '1'
        request['reason'] = 'reason text'
        request['currency'] = 'TRY'

        # make request
        cross_booking_to_sub_merchant = iyzipay.CrossBookingToSubMerchant()
        cross_booking_to_sub_merchant_response = cross_booking_to_sub_merchant.create(request, options)

        # print response
        pprint.pprint(cross_booking_to_sub_merchant_response.read().decode())

    def should_receive_money_from_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantKey'] = 'sub merchant key'
        request['price'] = '1'
        request['reason'] = 'reason text'
        request['currency'] = 'TRY'

        # make request
        cross_booking_from_sub_merchant = iyzipay.CrossBookingFromSubMerchant()
        cross_booking_from_sub_merchant_response = cross_booking_from_sub_merchant.create(request, options)

        # print response
        pprint.pprint(cross_booking_from_sub_merchant_response.read().decode())



import pprint
import unittest
import iyzipay


class RefundSample(unittest.TestCase):
    def runTest(self):
        self.should_refund()
        self.should_refund_charged_from_merchant()

    def should_refund(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['paymentTransactionId'] = '1'
        request['price'] = '0.1'
        request['ip'] = '85.34.78.112'
        request['currency'] = 'TRY'

        # make request
        refund = iyzipay.Refund()
        refund_response = refund.create(request, options)

        # print response
        pprint.pprint(refund_response.read().decode())

    def should_refund_charged_from_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['paymentTransactionId'] = '1'
        request['price'] = '0.1'
        request['ip'] = '85.34.78.112'

        # make request
        refund_charged_from_merchant = iyzipay.RefundChargedFromMerchant()
        refund_charged_from_merchant_response = refund_charged_from_merchant.create(request, options)

        # print response
        pprint.pprint(refund_charged_from_merchant_response.read().decode())



import pprint
import unittest
import iyzipay


class InstallmentSample(unittest.TestCase):
    def runTest(self):
        self.should_retrieve_installment_info()
        self.should_retrieve_installment_info_for_all_banks()

    def should_retrieve_installment_info(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['binNumber'] = '454671'
        request['price'] = '1'

        # make request
        installment_info = iyzipay.InstallmentInfo()
        installment_info_response = installment_info.retrieve(request, options)

        # print response
        pprint.pprint(installment_info_response.read().decode())

    def should_retrieve_installment_info_for_all_banks(self):

        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'

        # make request
        installment_info = iyzipay.InstallmentInfo()
        installment_info_response = installment_info.retrieve(request, options)

        # print response
        pprint.pprint(installment_info_response.read().decode())



import pprint
import unittest
import iyzipay


class ApiTestSample(unittest.TestCase):
    def runTest(self):
        self.should_test_api()

    def should_test_api(self):

        options = dict([('base_url', iyzipay.base_url)])

        # make request
        api_test = iyzipay.ApiTest()
        api_test_response = api_test.retrieve(options)

        # print response
        pprint.pprint(api_test_response.read().decode())



import pprint
import unittest
import iyzipay


class SubMerchantSample(unittest.TestCase):
    def runTest(self):
        self.should_create_personal_sub_merchant()
        self.should_create_private_sub_merchant()
        self.should_create_limited_company_sub_merchant()
        self.should_update_personal_sub_merchant()
        self.should_update_private_sub_merchant()
        self.should_update_limited_company_sub_merchant()
        self.should_retrieve_sub_merchant()

    def should_create_personal_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantExternalId'] = 'B49224'
        request['subMerchantType'] = 'PERSONAL'
        request['address'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        request['contactName'] = 'John'
        request['contactSurname'] = 'Doe'
        request['email'] = 'email@submerchantemail.com'
        request['gsmNumber'] = '+905350000000'
        request['name'] = 'John\'s market'
        request['iban'] = 'TR180006200119000006672315'
        request['identityNumber'] = '1234567890'
        request['currency'] = 'TRY'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.create(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())

    def should_create_private_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantExternalId'] = 'S49222'
        request['subMerchantType'] = 'PRIVATE_COMPANY'
        request['address'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        request['taxOffice'] = 'Tax Office'
        request['legalCompanyTitle'] = 'John Doe inc'
        request['email'] = 'email@submerchantemail.com'
        request['gsmNumber'] = '+905350000000'
        request['name'] = 'John\'s market'
        request['iban'] = 'TR180006200119000006672315'
        request['identityNumber'] = '31300864726'
        request['currency'] = 'TRY'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.create(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())

    def should_create_limited_company_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantExternalId'] = 'AS49224'
        request['subMerchantType'] = 'LIMITED_OR_JOINT_STOCK_COMPANY'
        request['address'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        request['taxOffice'] = 'Tax Office'
        request['taxNumber'] = '9261877'
        request['legalCompanyTitle'] = 'XYZ inc'
        request['email'] = 'email@submerchantemail.com'
        request['gsmNumber'] = '+905350000000'
        request['name'] = 'John\'s market'
        request['iban'] = 'TR180006200119000006672315'
        request['currency'] = 'TRY'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.create(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())

    def should_update_personal_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantKey'] = 'sub merchant key'
        request['iban'] = 'TR180006200119000006672315'
        request['address'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        request['contactName'] = 'Jane'
        request['contactSurname'] = 'Doe'
        request['email'] = 'email@submerchantemail.com'
        request['gsmNumber'] = '+905350000000'
        request['name'] = 'Jane\'s market'
        request['identityNumber'] = '31300864726'
        request['currency'] = 'TRY'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.update(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())

    def should_update_private_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantKey'] = 'sub merchant key'
        request['address'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        request['taxOffice'] = 'Tax Office'
        request['legalCompanyTitle'] = 'John Doe inc'
        request['email'] = 'email@submerchantemail.com'
        request['gsmNumber'] = '+905350000000'
        request['name'] = 'John\'s market'
        request['iban'] = 'TR180006200119000006672315'
        request['identityNumber'] = '31300864726'
        request['currency'] = 'TRY'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.update(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())

    def should_update_limited_company_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantKey'] = 'sub merchant key'
        request['address'] = 'Nidakule Göztepe, Merdivenköy Mah. Bora Sok. No:1'
        request['taxOffice'] = 'Tax Office'
        request['taxNumber'] = '9261877'
        request['legalCompanyTitle'] = 'ABC inc'
        request['email'] = 'email@submerchantemail.com'
        request['gsmNumber'] = '+905350000000'
        request['name'] = 'John\'s market'
        request['iban'] = 'TR180006200119000006672315'
        request['currency'] = 'TRY'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.update(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())

    def should_retrieve_sub_merchant(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['subMerchantExternalId'] = 'AS49224'

        # make request
        sub_merchant = iyzipay.SubMerchant()
        sub_merchant_response = sub_merchant.retrieve(request, options)

        # print response
        pprint.pprint(sub_merchant_response.read().decode())



import pprint
import unittest
import iyzipay


class RetrieveTransactionsSample(unittest.TestCase):
    def runTest(self):
        self.should_retrieve_payout_completed_transactions()
        self.should_retrieve_bounced_bank_transfers()

    def should_retrieve_payout_completed_transactions(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['date'] = '2016-01-22 19:13:00'

        # make request
        payout_completed_transactions_list = iyzipay.PayoutCompletedTransactionList()
        payout_completed_transactions_list_response = payout_completed_transactions_list.retrieve(request, options)

        # print response
        pprint.pprint(payout_completed_transactions_list_response.read().decode())

    def should_retrieve_bounced_bank_transfers(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['date'] = '2016-01-22 19:13:00'

        # make request
        bounced_bank_transfer_list = iyzipay.BouncedBankTransferList()
        bounced_bank_transfer_list_response = bounced_bank_transfer_list.retrieve(request, options)

        # print response
        pprint.pprint(bounced_bank_transfer_list_response.read().decode())



import pprint
import unittest
import iyzipay
import ast
import base64


class ConnectBKMSample(unittest.TestCase):
    def runTest(self):
        self.should_initialize_bkm()
        self.should_retrieve_bkm_auth()

    def should_initialize_bkm(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['price'] = '1'
        request['callbackUrl'] = 'https://www.merchant.com/callback'

        request['buyerId'] = '100'
        request['buyerEmail'] = 'email@email.com'
        request['buyerIp'] = '85.34.78.112'

        request['connectorName'] = 'connector name'

        request['installmentDetails'] = self.prepare_installment_details()

        # make request
        bkm_initialize = iyzipay.ConnectBKMInitialize()
        bkm_initialize_response = bkm_initialize.create(request, options)

        # get and print response
        response = bkm_initialize_response.read().decode()
        pprint.pprint(response)

        # generate html code to redirect to BKM
        response_data_dict = ast.literal_eval(response)
        html_response = base64.b64decode(response_data_dict['htmlContent'])
        pprint.pprint(html_response)

    def should_retrieve_bkm_auth(self):
        options = dict([('base_url', iyzipay.base_url)])
        options['api_key'] = iyzipay.api_key
        options['secret_key'] = iyzipay.secret_key

        request = dict([('locale', 'tr')])
        request['conversationId'] = '123456789'
        request['token'] = 'token'

        # make request
        bkm_auth = iyzipay.ConnectBKMAuth()
        bkm_auth_response = bkm_auth.retrieve(request, options)

        # print response
        pprint.pprint(bkm_auth_response.read().decode())

    def prepare_installment_details(self):
        installment_details = list()
        installment_details.append(self.isbank_installment_details())
        installment_details.append(self.finansbank_installment_details())
        installment_details.append(self.akbank_installment_details())
        installment_details.append(self.ykb_installment_details())
        installment_details.append(self.denizbank_installment_details())
        installment_details.append(self.halkbank_installment_details())
        return installment_details

    def isbank_installment_details(self):
        installment_detail = dict([('bankId', '64')])
        installment_prices = []

        single_installment = dict([('installmentNumber', '1',), ('totalPrice', '1')])
        two_installment = dict([('installmentNumber', '2',), ('totalPrice', '1.1')])
        three_installment = dict([('installmentNumber', '3',), ('totalPrice', '1.1')])
        six_installment = dict([('installmentNumber', '6',), ('totalPrice', '1.2')])
        nine_installment = dict([('installmentNumber', '9',), ('totalPrice', '1.4')])

        installment_prices.append(single_installment)
        installment_prices.append(two_installment)
        installment_prices.append(three_installment)
        installment_prices.append(six_installment)
        installment_prices.append(nine_installment)

        installment_detail['installmentPrices'] = installment_prices

        return installment_detail

    def finansbank_installment_details(self):
        installment_detail = dict([('bankId', '111')])
        installment_prices = []

        single_installment = dict([('installmentNumber', '1',), ('totalPrice', '1')])
        two_installment = dict([('installmentNumber', '2',), ('totalPrice', '1.1')])
        three_installment = dict([('installmentNumber', '3',), ('totalPrice', '1.1')])
        six_installment = dict([('installmentNumber', '6',), ('totalPrice', '1.2')])
        nine_installment = dict([('installmentNumber', '9',), ('totalPrice', '1.4')])

        installment_prices.append(single_installment)
        installment_prices.append(two_installment)
        installment_prices.append(three_installment)
        installment_prices.append(six_installment)
        installment_prices.append(nine_installment)

        installment_detail['installmentPrices'] = installment_prices

        return installment_detail

    def akbank_installment_details(self):
        installment_detail = dict([('bankId', '46')])
        installment_prices = []

        single_installment = dict([('installmentNumber', '1',), ('totalPrice', '1')])
        two_installment = dict([('installmentNumber', '2',), ('totalPrice', '1.1')])
        three_installment = dict([('installmentNumber', '3',), ('totalPrice', '1.1')])
        six_installment = dict([('installmentNumber', '6',), ('totalPrice', '1.2')])
        nine_installment = dict([('installmentNumber', '9',), ('totalPrice', '1.4')])

        installment_prices.append(single_installment)
        installment_prices.append(two_installment)
        installment_prices.append(three_installment)
        installment_prices.append(six_installment)
        installment_prices.append(nine_installment)

        installment_detail['installmentPrices'] = installment_prices

        return installment_detail

    def ykb_installment_details(self):
        installment_detail = dict([('bankId', '67')])
        installment_prices = []

        single_installment = dict([('installmentNumber', '1',), ('totalPrice', '1')])
        two_installment = dict([('installmentNumber', '2',), ('totalPrice', '1.1')])
        three_installment = dict([('installmentNumber', '3',), ('totalPrice', '1.1')])
        six_installment = dict([('installmentNumber', '6',), ('totalPrice', '1.2')])
        nine_installment = dict([('installmentNumber', '9',), ('totalPrice', '1.4')])

        installment_prices.append(single_installment)
        installment_prices.append(two_installment)
        installment_prices.append(three_installment)
        installment_prices.append(six_installment)
        installment_prices.append(nine_installment)

        installment_detail['installmentPrices'] = installment_prices

        return installment_detail

    def denizbank_installment_details(self):
        installment_detail = dict([('bankId', '134')])
        installment_prices = []

        single_installment = dict([('installmentNumber', '1',), ('totalPrice', '1')])
        two_installment = dict([('installmentNumber', '2',), ('totalPrice', '1.1')])
        three_installment = dict([('installmentNumber', '3',), ('totalPrice', '1.1')])
        six_installment = dict([('installmentNumber', '6',), ('totalPrice', '1.2')])
        nine_installment = dict([('installmentNumber', '9',), ('totalPrice', '1.4')])

        installment_prices.append(single_installment)
        installment_prices.append(two_installment)
        installment_prices.append(three_installment)
        installment_prices.append(six_installment)
        installment_prices.append(nine_installment)

        installment_detail['installmentPrices'] = installment_prices

        return installment_detail

    def halkbank_installment_details(self):
        installment_detail = dict([('bankId', '12')])
        installment_prices = []

        single_installment = dict([('installmentNumber', '1',), ('totalPrice', '1')])
        two_installment = dict([('installmentNumber', '2',), ('totalPrice', '1.1')])
        three_installment = dict([('installmentNumber', '3',), ('totalPrice', '1.1')])
        six_installment = dict([('installmentNumber', '6',), ('totalPrice', '1.2')])
        nine_installment = dict([('installmentNumber', '9',), ('totalPrice', '1.4')])

        installment_prices.append(single_installment)
        installment_prices.append(two_installment)
        installment_prices.append(three_installment)
        installment_prices.append(six_installment)
        installment_prices.append(nine_installment)

        installment_detail['installmentPrices'] = installment_prices

        return installment_detail


